@@ -17,18 +17,29 @@
 
 package org.apache.streampark.console.base.domain;
 
+import io.swagger.v3.oas.annotations.media.Schema;
 import lombok.Data;
+import org.springdoc.api.annotations.ParameterObject;
 
 import java.io.Serializable;
 
+@ParameterObject
 @Data
 public class RestRequest implements Serializable {
 
   private static final long serialVersionUID = -4869594085374385813L;
 
+  @Schema(example = "10", required = true)
   private int pageSize = 10;
+
+  @Schema(example = "1", required = true)
   private int pageNum = 1;
 
+  @Schema(example = "", description = "e.g. create_time")
   private String sortField;
+
+  @Schema(
+      example = "",
+      allowableValues = {"asc", "desc"})
   private String sortOrder;
 }
