@@ -18,20 +18,19 @@
 package org.apache.streampark.console.core.bean;
 
 import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
-import io.swagger.annotations.ApiModel;
-import io.swagger.annotations.ApiModelProperty;
+import io.swagger.v3.oas.annotations.media.Schema;
 import lombok.Data;
 
 import javax.validation.constraints.NotBlank;
 
 import java.io.Serializable;
 
-@ApiModel(value = "AlertWeCom")
+@Schema(name = "AlertWeCom")
 @Data
 @JsonIgnoreProperties(ignoreUnknown = true)
 public class AlertWeComParams implements Serializable {
 
-  @ApiModelProperty(name = "token", value = "we-com token")
+  @Schema(name = "token", description = "we-com token")
   @NotBlank(message = "The access token of WeCom must be not empty")
   private String token;
 }
