@@ -17,19 +17,21 @@
 
 package org.apache.streampark.flink.client.bean
 
-import java.util.{Map => JavaMap}
-import javax.annotation.Nullable
-
 import org.apache.streampark.common.conf.{FlinkVersion, K8sFlinkConfig}
 import org.apache.streampark.common.enums.ExecutionMode
 
+import javax.annotation.Nullable
+
+import java.util.{Map => JavaMap}
+
 case class CancelRequest(
     flinkVersion: FlinkVersion,
     executionMode: ExecutionMode,
+    @Nullable properties: JavaMap[String, Any],
     clusterId: String,
     jobId: String,
-    withSavePoint: Boolean,
+    override val withSavepoint: Boolean,
     withDrain: Boolean,
-    customSavePointPath: String,
-    kubernetesNamespace: String = K8sFlinkConfig.DEFAULT_KUBERNETES_NAMESPACE,
-    @Nullable properties: JavaMap[String, Any])
+    savepointPath: String,
+    override val kubernetesNamespace: String = K8sFlinkConfig.DEFAULT_KUBERNETES_NAMESPACE)
+  extends SavepointRequestTrait
