@@ -17,17 +17,22 @@
 
 package org.apache.streampark.flink.core
 
-import java.util.concurrent.CompletableFuture
-
 import org.apache.flink.api.common.JobID
 import org.apache.flink.client.program.ClusterClient
 
+import java.util.concurrent.CompletableFuture
+
 abstract class FlinkClientTrait[T](clusterClient: ClusterClient[T]) {
 
+  def triggerSavepoint(jobID: JobID, savepointDir: String): CompletableFuture[String] = {
+    clusterClient.triggerSavepoint(jobID, savepointDir)
+  }
+
   def cancelWithSavepoint(jobID: JobID, s: String): CompletableFuture[String] = {
     clusterClient.cancelWithSavepoint(jobID, s)
   }
 
-  def stopWithSavepoint(jobID: JobID, b: Boolean, s: String): CompletableFuture[String] = clusterClient.stopWithSavepoint(jobID, b, s)
+  def stopWithSavepoint(jobID: JobID, b: Boolean, s: String): CompletableFuture[String] =
+    clusterClient.stopWithSavepoint(jobID, b, s)
 
 }
