@@ -16,16 +16,16 @@
  */
 package org.apache.streampark.flink.core
 
+import org.apache.streampark.common.conf.ConfigConst.printLogo
+
 import org.apache.flink.api.common.JobExecutionResult
 import org.apache.flink.api.java.utils.ParameterTool
-import org.apache.flink.table.api.{Table, TableEnvironment}
-import org.apache.flink.table.descriptors.{ConnectorDescriptor, ConnectTableDescriptor}
+import org.apache.flink.table.api.{Table, TableDescriptor, TableEnvironment}
 import org.apache.flink.table.module.ModuleEntry
 import org.apache.flink.table.sources.TableSource
 
-import org.apache.streampark.common.conf.ConfigConst.printLogo
-
-class TableContext(override val parameter: ParameterTool, private val tableEnv: TableEnvironment) extends FlinkTableTrait(parameter, tableEnv) {
+class TableContext(override val parameter: ParameterTool, private val tableEnv: TableEnvironment)
+  extends FlinkTableTrait(parameter, tableEnv) {
 
   /**
    * for scala
@@ -39,29 +39,51 @@ class TableContext(override val parameter: ParameterTool, private val tableEnv:
    *
    * @param args
    */
-  def this(args: TableEnvConfig) = this(FlinkTableInitializer.initialize(args))
+  def this(args: TableEnvConfig) = {
+    this(FlinkTableInitializer.initialize(args))
+  }
 
   override def useModules(strings: String*): Unit = tableEnv.useModules(strings: _*)
 
   override def listFullModules(): Array[ModuleEntry] = tableEnv.listFullModules()
 
-  @deprecated override def connect(connectorDescriptor: ConnectorDescriptor): ConnectTableDescriptor = tableEnv.connect(connectorDescriptor)
+  /**
+   * flink 1.14, need to implement
+   *
+   * @param path
+   * @param descriptor
+   */
+  def createTable(path: String, descriptor: TableDescriptor): Unit = {
+    tableEnv.createTable(path, descriptor)
+  }
 
-  override def execute(jobName: String): JobExecutionResult = {
+  def createTemporaryTable(path: String, descriptor: TableDescriptor): Unit = {
+    tableEnv.createTemporaryTable(path, descriptor)
+  }
+
+  def from(descriptor: TableDescriptor): Table = tableEnv.from(descriptor)
+
+  @deprecated override def execute(jobName: String): JobExecutionResult = {
     printLogo(s"FlinkTable $jobName Starting...")
     tableEnv.execute(jobName)
   }
 
-  @deprecated override def fromTableSource(source: TableSource[_]): Table = tableEnv.fromTableSource(source)
+  @deprecated override def fromTableSource(source: TableSource[_]): Table =
+    tableEnv.fromTableSource(source)
 
-  @deprecated override def insertInto(table: Table, sinkPath: String, sinkPathContinued: String*): Unit =
+  @deprecated override def insertInto(
+      table: Table,
+      sinkPath: String,
+      sinkPathContinued: String*): Unit =
     tableEnv.insertInto(table, sinkPath, sinkPathContinued: _*)
 
-  @deprecated override def insertInto(targetPath: String, table: Table): Unit = tableEnv.insertInto(targetPath, table)
+  @deprecated override def insertInto(targetPath: String, table: Table): Unit =
+    tableEnv.insertInto(targetPath, table)
 
   @deprecated override def explain(table: Table): String = tableEnv.explain(table)
 
-  @deprecated override def explain(table: Table, extended: Boolean): String = tableEnv.explain(table, extended)
+  @deprecated override def explain(table: Table, extended: Boolean): String =
+    tableEnv.explain(table, extended)
 
   @deprecated override def explain(extended: Boolean): String = tableEnv.explain(extended)
 
